# -*- mode: python -*-
# -*- coding: utf-8 -*-

##############################################################################
#
# Gestion scolarite IUT
#
# Copyright (c) 1999 - 2021 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@gmail.com
#
##############################################################################

"""Imports et configuration des composants Zope
"""
# Avoid pylint warnings when linting without Zope
# pylint: skip-file

# Allows code linting on platforms without Zope:
# pylint: disable=import-error
from OFS.SimpleItem import Item  # Basic zope object
from OFS.PropertyManager import PropertyManager  # provide the 'Properties' tab with the

# 'manage_propertiesForm' method
from OFS.ObjectManager import ObjectManager
from AccessControl.Role import RoleManager  # provide the 'Ownership' tab with

# the 'manage_owner' method
from AccessControl import ClassSecurityInfo as ZopeClassSecurityInfo
import Globals
from Globals import DTMLFile  # can use DTML files
from Globals import Persistent
from Globals import INSTANCE_HOME
from Acquisition import Implicit


# Collect all security declarations (Zope2Flask)

import inspect

LOG_SECURITY = False  # use for dev


class ClassSecurityInfo(ZopeClassSecurityInfo):
    def declareProtected(self, perm, funcname):
        if LOG_SECURITY:
            frame = inspect.currentframe()
            module = str(frame.f_back.f_locals["__module__"])
            assert module.startswith("Products.ScoDoc.")
            module = module[len("Products.ScoDoc.") :]
            with open("/tmp/protected_methods.txt", "a") as f:
                f.write("%s\t%s\n" % (module, funcname))
        super(ClassSecurityInfo, self).declareProtected(perm, funcname)
